# Contributing to VersionOne SDK.Python

 1. [Getting Involved](#getting-involved)
 2. [Reporting Bugs](#reporting-bugs)
 3. [Contributing Code](#contributing-code)

## Getting Involved

We need your help to make VersionOne SDK.Python a useful integration. While third-party patches are absolutely essential, they are not the only way to get involved. You can help the project by discovering and [reporting bugs](#reporting-bugs) and helping others on the [versionone-dev group](http://groups.google.com/group/versionone-dev/) and [GitHub issues][issues].

## Reporting Bugs

Before reporting a bug on the project's [issues page][issues], first make sure that your issue is caused by VersionOne Integration for Buy A Feature, not your application code (e.g. passing incorrect arguments to methods, etc.). Second, search the already reported issues for similar cases, and if it has been reported already, just add any additional details in the comments.

After you made sure that you have found a new bug, here are some tips for creating a helpful report that will make fixing it much easier and quicker:

 * Write a **descriptive, specific title**. Bad: *Problem with filtering*. Good: *Scope.GetThisAndAllChildProjects() always returns an empty list*.
 * Whenever possible, include **Class and Method** info in the description.
 * Create a **simple test case** that demonstrates the bug (e.g. using [NUnit](http://www.nunit.org/)).
 
## Contributing Code

All pull requests are welcome as long as they have a clear explanation.
Maintainers needed!
If you'd like to be a maintainer, contact [Mike Alexander](mailto:mikealexander1860@gmail.com)

[issues]: https://github.com/versionone/VersionOne.SDK.Python/issues